==> medlogics-common-classes-1.5.3.jar: com/floreantpos/model/dao/PayOutTransactionDAO.java <==
/**
 * ************************************************************************
 * * The contents of this file are subject to the MRPL 1.2
 * * (the  "License"),  being   the  Mozilla   Public  License
 * * Version 1.1  with a permitted attribution clause; you may not  use this
 * * file except in compliance with the License. You  may  obtain  a copy of
 * * the License at http://www.floreantpos.org/license.html
 * * Software distributed under the License  is  distributed  on  an "AS IS"
 * * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * * License for the specific  language  governing  rights  and  limitations
 * * under the License.
 * * The Original Code is FLOREANT POS.
 * * The Initial Developer of the Original Code is OROCUBE LLC
 * * All portions are Copyright (C) 2015 OROCUBE LLC
 * * All Rights Reserved.
 * ************************************************************************
 */
package com.floreantpos.model.dao;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

import org.apache.commons.lang.StringUtils;
import org.hibernate.Criteria;
import org.hibernate.Session;
import org.hibernate.Transaction;
import org.hibernate.criterion.MatchMode;
import org.hibernate.criterion.Order;
import org.hibernate.criterion.Restrictions;

import com.floreantpos.model.CashDrawer;
import com.floreantpos.model.Pagination;
import com.floreantpos.model.PayOutTransaction;
import com.floreantpos.model.PaymentType;
import com.floreantpos.model.PayoutReason;
import com.floreantpos.model.PayoutRecepient;
import com.floreantpos.model.PosTransaction;
import com.floreantpos.model.StoreSession;
import com.floreantpos.model.Terminal;
import com.floreantpos.model.TransactionType;
import com.floreantpos.model.User;
import com.floreantpos.model.util.DataProvider;
import com.floreantpos.swing.PaginationSupport;

public class PayOutTransactionDAO extends BasePayOutTransactionDAO {

	/**
	 * Default constructor.  Can be used in place of getInstance()
	 */
	public PayOutTransactionDAO() {
	}

	@Override
	protected Serializable save(Object obj, Session s) {
		updateTime(obj);
		return super.save(obj, s);
	}

	@Override
	protected void update(Object obj, Session s) {
		updateTime(obj);
		super.update(obj, s);
	}

	@Override
	protected void saveOrUpdate(Object obj, Session s) {
		updateTime(obj);
		super.saveOrUpdate(obj, s);
	}

	public void saveTransaction(PayOutTransaction t, Terminal terminal) throws Exception {
		Transaction tx = null;

		try (Session session = createNewSession()) {
			tx = session.beginTransaction();
			session.saveOrUpdate(t);
			if (terminal != null) {
				session.saveOrUpdate(terminal);
			}
			//			PosTransactionService.getInstance().adjustMulticurrencyBalance(session, terminal, t.getCashDrawer(), null, t);
			tx.commit();

		} catch (Exception e) {
			try {
				tx.rollback();
			} catch (Exception x) {
			}
			throw e;
		}
	}

	public void createPayoutTransaction(PayoutReason reason, PayoutRecepient recepient, String note, double payoutAmount, User currentUser,
			Terminal drawerTerminal, CashDrawer cashDrawer) throws Exception {
		createPayoutTransaction(reason, recepient, note, payoutAmount, currentUser, drawerTerminal, cashDrawer, "", null, false);
	}

	public void createPayoutTransaction(PayoutReason reason, PayoutRecepient recepient, String note, double payoutAmount, User currentUser,
			Terminal drawerTerminal, CashDrawer cashDrawer, String batchNo, Date transactionTime, boolean isExpenses) throws Exception {
		StoreSession storeSession = DataProvider.get().getStoreSession();
		if (storeSession == null && cashDrawer != null) {
			storeSession = cashDrawer.getStoreSession();
		}

		PayOutTransaction payOutTransaction = new PayOutTransaction();
		payOutTransaction.setPaymentType(PaymentType.CASH);
		payOutTransaction.setTransactionType(TransactionType.OUT.name());

		payOutTransaction.setReason(reason);
		payOutTransaction.setRecepient(recepient);
		payOutTransaction.setNote(note);
		if (StringUtils.isNotBlank(batchNo)) {
			payOutTransaction.setBatchNo(batchNo);
		}
		payOutTransaction.setAmount(Double.valueOf(payoutAmount));

		payOutTransaction.setCashDrawer(cashDrawer);
		if (storeSession != null) {
			payOutTransaction.setStoreSessionId(storeSession.getId());
		}
		payOutTransaction.setUser(currentUser);
		payOutTransaction.setServer(currentUser);
		if (transactionTime != null) {
			payOutTransaction.setTransactionTime(transactionTime);
		}
		else {
			payOutTransaction.setTransactionTime(new Date());
		}
		if (drawerTerminal != null) {
			payOutTransaction.setTerminal(drawerTerminal);
		}
		payOutTransaction.putExpenses(isExpenses);
		saveTransaction(payOutTransaction, drawerTerminal);

		LedgerEntryDAO.getInstance().savePayoutLedgerEntry(payOutTransaction);

	}

	public List<PayOutTransaction> getUnsettled(Terminal terminal, User cashier) {
		try (Session session = createNewSession()) {
			Criteria criteria = session.createCriteria(getReferenceClass());
			criteria.add(Restrictions.eq(PayOutTransaction.PROP_DRAWER_RESETTED, Boolean.FALSE));
			if (cashier == null) {
				criteria.add(Restrictions.eq(PayOutTransaction.PROP_TERMINAL_ID, terminal == null ? null : terminal.getId()));
				//criteria.add(Restrictions.ne("paymentReceiver", DrawerType.STAFF_BANK));
			}
			else {
				criteria.add(Restrictions.eq(PayOutTransaction.PROP_USER_ID, cashier.getId()));
				//criteria.add(Restrictions.eq("paymentReceiver", DrawerType.STAFF_BANK));
			}

			List list = criteria.list();
			return list;
		}
	}

	public List<PayOutTransaction> findPayoutReport(Date fromDate, Date toDate, String batchNo) {
		return findPayoutReport(fromDate, toDate, batchNo, false);
	}

	public List<PayOutTransaction> findPayoutReport(Date fromDate, Date toDate, String batchNo, boolean isShowExpenseOnly) {
		Pagination pagination = new Pagination<>(0, -1);
		findPayoutReport(fromDate, toDate, batchNo, isShowExpenseOnly, pagination);
		return pagination.getDataList();
	}

	public void findPayoutReport(Date fromDate, Date toDate, String batchNo, boolean isShowExpenseOnly, PaginationSupport listModel) {
		try (Session session = createNewSession()) {
			Criteria criteria = session.createCriteria(getReferenceClass());
			criteria.add(Restrictions.eq(PayOutTransaction.PROP_DRAWER_RESETTED, Boolean.FALSE));

			if (fromDate != null && toDate != null) {
				criteria.add(Restrictions.between(PayOutTransaction.PROP_TRANSACTION_TIME, fromDate, toDate));
			}
			if (StringUtils.isNotBlank(batchNo)) {
				criteria.add(Restrictions.eq(PosTransaction.PROP_BATCH_NO, batchNo));
			}

			if (isShowExpenseOnly) {
				criteria.add(Restrictions.ilike(PayOutTransaction.PROP_EXTRA_PROPERTIES, "\"expenses\":\"true\"", MatchMode.ANYWHERE));
			}
			else {
				criteria.add(Restrictions.not(Restrictions.ilike(PayOutTransaction.PROP_EXTRA_PROPERTIES, "\"expenses\":\"true\"", MatchMode.ANYWHERE)));
			}

			listModel.setNumRows(rowCount(criteria));

			criteria.setFirstResult(listModel.getCurrentRowIndex());
			criteria.setMaxResults(listModel.getPageSize());
			criteria.addOrder(Order.desc(PayOutTransaction.PROP_TRANSACTION_TIME));
			listModel.setRows(criteria.list());
		}
	}
}

==> medlogics-common-classes-1.6.0.jar: com/floreantpos/model/dao/PayOutTransactionDAO.java <==
/**
 * ************************************************************************
 * * The contents of this file are subject to the MRPL 1.2
 * * (the  "License"),  being   the  Mozilla   Public  License
 * * Version 1.1  with a permitted attribution clause; you may not  use this
 * * file except in compliance with the License. You  may  obtain  a copy of
 * * the License at http://www.floreantpos.org/license.html
 * * Software distributed under the License  is  distributed  on  an "AS IS"
 * * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * * License for the specific  language  governing  rights  and  limitations
 * * under the License.
 * * The Original Code is FLOREANT POS.
 * * The Initial Developer of the Original Code is OROCUBE LLC
 * * All portions are Copyright (C) 2015 OROCUBE LLC
 * * All Rights Reserved.
 * ************************************************************************
 */
package com.floreantpos.model.dao;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

import org.apache.commons.lang.StringUtils;
import org.hibernate.Criteria;
import org.hibernate.Session;
import org.hibernate.Transaction;
import org.hibernate.criterion.MatchMode;
import org.hibernate.criterion.Order;
import org.hibernate.criterion.Restrictions;

import com.floreantpos.model.CashDrawer;
import com.floreantpos.model.Pagination;
import com.floreantpos.model.PayOutTransaction;
import com.floreantpos.model.PaymentType;
import com.floreantpos.model.PayoutReason;
import com.floreantpos.model.PayoutRecepient;
import com.floreantpos.model.PosTransaction;
import com.floreantpos.model.StoreSession;
import com.floreantpos.model.Terminal;
import com.floreantpos.model.TransactionType;
import com.floreantpos.model.User;
import com.floreantpos.model.util.DataProvider;
import com.floreantpos.swing.PaginationSupport;

public class PayOutTransactionDAO extends BasePayOutTransactionDAO {

	/**
	 * Default constructor.  Can be used in place of getInstance()
	 */
	public PayOutTransactionDAO() {
	}

	@Override
	protected Serializable save(Object obj, Session s) {
		updateTime(obj);
		return super.save(obj, s);
	}

	@Override
	protected void update(Object obj, Session s) {
		updateTime(obj);
		super.update(obj, s);
	}

	@Override
	protected void saveOrUpdate(Object obj, Session s) {
		updateTime(obj);
		super.saveOrUpdate(obj, s);
	}

	public void saveTransaction(PayOutTransaction t, Terminal terminal) throws Exception {
		Transaction tx = null;

		try (Session session = createNewSession()) {
			tx = session.beginTransaction();
			session.saveOrUpdate(t);
			if (terminal != null) {
				session.saveOrUpdate(terminal);
			}
			//			PosTransactionService.getInstance().adjustMulticurrencyBalance(session, terminal, t.getCashDrawer(), null, t);
			tx.commit();

		} catch (Exception e) {
			try {
				tx.rollback();
			} catch (Exception x) {
			}
			throw e;
		}
	}

	public void createPayoutTransaction(PayoutReason reason, PayoutRecepient recepient, String note, double payoutAmount, User currentUser,
			Terminal drawerTerminal, CashDrawer cashDrawer) throws Exception {
		createPayoutTransaction(reason, recepient, note, payoutAmount, currentUser, drawerTerminal, cashDrawer, "", null, false);
	}

	public void createPayoutTransaction(PayoutReason reason, PayoutRecepient recepient, String note, double payoutAmount, User currentUser,
			Terminal drawerTerminal, CashDrawer cashDrawer, String batchNo, Date transactionTime, boolean isExpenses) throws Exception {
		StoreSession storeSession = DataProvider.get().getStoreSession();
		if (storeSession == null && cashDrawer != null) {
			storeSession = cashDrawer.getStoreSession();
		}

		PayOutTransaction payOutTransaction = new PayOutTransaction();
		payOutTransaction.setPaymentType(PaymentType.CASH);
		payOutTransaction.setTransactionType(TransactionType.OUT.name());

		payOutTransaction.setReason(reason);
		payOutTransaction.setRecepient(recepient);
		payOutTransaction.setNote(note);
		if (StringUtils.isNotBlank(batchNo)) {
			payOutTransaction.setBatchNo(batchNo);
		}
		payOutTransaction.setAmount(Double.valueOf(payoutAmount));

		payOutTransaction.setCashDrawer(cashDrawer);
		if (storeSession != null) {
			payOutTransaction.setStoreSessionId(storeSession.getId());
		}
		payOutTransaction.setUser(currentUser);
		payOutTransaction.setServer(currentUser);
		if (transactionTime != null) {
			payOutTransaction.setTransactionTime(transactionTime);
		}
		else {
			payOutTransaction.setTransactionTime(new Date());
		}
		if (drawerTerminal != null) {
			payOutTransaction.setTerminal(drawerTerminal);
		}
		payOutTransaction.putExpenses(isExpenses);
		saveTransaction(payOutTransaction, drawerTerminal);

		LedgerEntryDAO.getInstance().savePayoutLedgerEntry(payOutTransaction);

	}

	public List<PayOutTransaction> getUnsettled(Terminal terminal, User cashier) {
		try (Session session = createNewSession()) {
			Criteria criteria = session.createCriteria(getReferenceClass());
			criteria.add(Restrictions.eq(PayOutTransaction.PROP_DRAWER_RESETTED, Boolean.FALSE));
			if (cashier == null) {
				criteria.add(Restrictions.eq(PayOutTransaction.PROP_TERMINAL_ID, terminal == null ? null : terminal.getId()));
				//criteria.add(Restrictions.ne("paymentReceiver", DrawerType.STAFF_BANK));
			}
			else {
				criteria.add(Restrictions.eq(PayOutTransaction.PROP_USER_ID, cashier.getId()));
				//criteria.add(Restrictions.eq("paymentReceiver", DrawerType.STAFF_BANK));
			}

			List list = criteria.list();
			return list;
		}
	}

	public List<PayOutTransaction> findPayoutReport(Date fromDate, Date toDate, String batchNo) {
		return findPayoutReport(fromDate, toDate, batchNo, false);
	}

	public List<PayOutTransaction> findPayoutReport(Date fromDate, Date toDate, String batchNo, boolean isShowExpenseOnly) {
		return findPayoutReport(fromDate, toDate, batchNo, null, null, isShowExpenseOnly);
	}

	public List<PayOutTransaction> findPayoutReport(Date fromDate, Date toDate, String batchNo, String recipientId, String reasonId,
			boolean isShowExpenseOnly) {
		Pagination pagination = new Pagination<>(0, -1);
		findPayoutReport(fromDate, toDate, batchNo, recipientId, reasonId, isShowExpenseOnly, pagination);
		return pagination.getDataList();
	}

	public void findPayoutReport(Date fromDate, Date toDate, String batchNo, String recipientId, String reasonId, boolean isShowExpenseOnly,
			PaginationSupport listModel) {
		try (Session session = createNewSession()) {
			Criteria criteria = session.createCriteria(getReferenceClass());
			criteria.add(Restrictions.eq(PayOutTransaction.PROP_DRAWER_RESETTED, Boolean.FALSE));

			if (fromDate != null && toDate != null) {
				criteria.add(Restrictions.between(PayOutTransaction.PROP_TRANSACTION_TIME, fromDate, toDate));
			}
			if (StringUtils.isNotBlank(batchNo)) {
				criteria.add(Restrictions.eq(PosTransaction.PROP_BATCH_NO, batchNo));
			}
			if (StringUtils.isNotBlank(recipientId)) {
				criteria.add(Restrictions.eq(PosTransaction.PROP_RECEPIENT_ID, recipientId));
			}
			if (StringUtils.isNotBlank(reasonId)) {
				criteria.add(Restrictions.eq(PosTransaction.PROP_REASON_ID, reasonId));
			}

			if (isShowExpenseOnly) {
				criteria.add(Restrictions.ilike(PayOutTransaction.PROP_EXTRA_PROPERTIES, "\"expenses\":\"true\"", MatchMode.ANYWHERE));
			}
			else {
				criteria.add(Restrictions.not(Restrictions.ilike(PayOutTransaction.PROP_EXTRA_PROPERTIES, "\"expenses\":\"true\"", MatchMode.ANYWHERE)));
			}

			listModel.setNumRows(rowCount(criteria));

			criteria.setFirstResult(listModel.getCurrentRowIndex());
			criteria.setMaxResults(listModel.getPageSize());
			criteria.addOrder(Order.desc(PayOutTransaction.PROP_TRANSACTION_TIME));
			listModel.setRows(criteria.list());
		}
	}
}
